consistency_scoring: Calculate consistency scores

Description Usage Arguments See Also

View source: R/consistency_scoring.R

Description

Calculates consistency scores using data from a consistency test for synesthesia. Can also create plots for each data set (using the synratss::plot_syn_cons function).

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
consistency_scoring(
  part_df,
  id_col_name,
  timestamp_col_name,
  plotdir = NULL,
  method = "euclidean",
  fmt = "Luv",
  nameby = NULL,
  swedish_chars = FALSE,
  swedish_weekdays = FALSE,
  participant_ids = NULL,
  category_lines = FALSE,
  multi_char_category = FALSE
)

Arguments

part_df

participant consistency test raw data frame

plotdir

(optional) directory path for directory to put plots in

method

method to use in color space distance calculations ("euclidean" for Euclidean distances, "manhattan" for Manhattan/city block distances - "euclidean" is standard)

fmt

specifies color format/space to be used ("sRGB", "Luv")

nameby

(optional) name, in quotes, of column to name output plots by, e. g. "USERNAME"

swedish_chars

specify if swedish characters are in the data frame or not

swedish_weekdays

specify if swedish weekdays are in the data frame or not

participant_ids

a vector for naming output plots. needs to be in the same order as the part_df participants.

category_lines

if TRUE and plotdir is set, drawn plots will include lines representing the mean score per category

multi_char_category

if TRUE, plotdir is set, and category_lines is TRUE, category lines will include a line for representing mean score of multi character category

See Also

prop_col dist_sum plot_syn_cons


AnonZebra/synratss documentation built on Oct. 9, 2021, 2:31 a.m.