prop_col: Calculate proportion of color codes within specified color...

Description Usage Arguments See Also

View source: R/prop_col.R

Description

Calculates the proportion of color values in a data frame that fall within a color range, specified using the col argument. Possible choices are "black", "white", "blue" and "hazy", with "black" as default. Returns NA if all values in the data frame are NA.

Usage

1
prop_col(hexdf, col = "black", byrow = FALSE)

Arguments

hexdf

data frame with hexadecimal color values

col

1-value character vector, specifying color range

byrow

1-value character vector, specifying if function should calculate the proportion of rows (TRUE) where all values fall within color range, or the proportion of elements (FALSE - default).

See Also

is_color


AnonZebra/synratss documentation built on Oct. 9, 2021, 2:31 a.m.