Description Usage Arguments See Also
Calculates the proportion of color values in a data frame that fall within a color range, specified using the col argument. Possible choices are "black", "white", "blue" and "hazy", with "black" as default. Returns NA if all values in the data frame are NA.
1 |
hexdf |
data frame with hexadecimal color values |
col |
1-value character vector, specifying color range |
byrow |
1-value character vector, specifying if function should calculate the proportion of rows (TRUE) where all values fall within color range, or the proportion of elements (FALSE - default). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.